@@ -33,7 +33,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   use vars qw($VERSION);
   my $CommonLib = new Apache2::AMFCommonLib ();
-  $VERSION= "3.07";
+  $VERSION= "3.08";
   my %Capability;
   my %Array_fb;
   my %Array_id;
@@ -42,6 +42,7 @@ package Apache2::AMFWURFLFilterMemcached;
 
   my %PatchArray_id;
   my %MobileArray;
+  my %PCArray;
   $MobileArray{'mobile'}='mobile';
   $MobileArray{'symbian'}='mobile';
   $MobileArray{'midp'}='mobile';
@@ -51,6 +52,15 @@ package Apache2::AMFWURFLFilterMemcached;
   $MobileArray{'google'}='mobile';
   $MobileArray{'novarra'}='mobile';
   $MobileArray{'htc'}='mobile';
+  $MobileArray{'windows ce'}='mobile';
+  $MobileArray{'palm'}='mobile';
+  $MobileArray{'lge'}='mobile';
+  $MobileArray{'brew'}='mobile';
+  $MobileArray{'webos'}='mobile';
+  $PCArray{'MSIE'}='msie';
+  $PCArray{'MSIE 6'}='msie_6';
+  $PCArray{'MSIE 7'}='msie_7';
+  $PCArray{'MSIE 8'}='msie_8';
   my $mobileversionurl="none";
   my $fullbrowserurl="none";
   my $redirecttranscoder="true";
@@ -65,6 +75,7 @@ package Apache2::AMFWURFLFilterMemcached;
   my $cookiecachesystem="false";
   my $WURFLVersion="unknown";  
   my $serverMemCache;
+  my $restmode='false';
   
   $CommonLib->printLog("---------------------------------------------------------------------------"); 
   $CommonLib->printLog("-------                 APACHE MOBILE FILTER V$VERSION                  -------");
@@ -321,6 +332,10 @@ sub loadConfigFile {
         $CommonLib->printLog("WURFL version: $WURFLVersion");
         $CommonLib->printLog("This version of WURFL has $arrLen UserAgent");
         $CommonLib->printLog("End loading  WURFL.xml");
+	if ($ENV{RestMode}) {
+		$restmode=$ENV{RestMode};
+		$CommonLib->printLog("RestMode is: $restmode");
+	}
 }
 sub FallBack {
   my ($idToFind) = @_;
@@ -385,12 +400,18 @@ sub IdentifyPCUAMethod {
   my $id_find="";
   my $pair;
   my $length=0;
-
-  foreach $pair (%PatchArray_id)
-  {  
-       if (index($UserAgent,$pair) > -1) {
-           	$id_find=$PatchArray_id{$pair};
-       }
+  foreach $pair (sort %PCArray) {
+	if ($UserAgent =~ m/$pair/) {
+		$id_find=$PCArray{$pair};
+	}
+  }
+  if ($id_find eq "") { 
+	foreach $pair (%PatchArray_id)
+	{  
+	     if (index($UserAgent,$pair) > -1) {
+		      $id_find=$PatchArray_id{$pair};
+	     }
+	}
   }
   return $id_find;
 }
@@ -547,7 +568,24 @@ sub handler {
     if ($x_operamini_phone_ua) {
        $user_agent=$x_operamini_phone_ua;
     }
-    
+    if (($query_string) && $restmode eq 'true') {
+    		  my @vars = split(/&/, $query_string); 	  
+    		  foreach $var (sort @vars){
+    				   if ($var) {
+    						my ($v,$i) = split(/=/, $var);
+    						$v =~ tr/+/ /;
+    						$v =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
+    						$i =~ tr/+/ /;
+    						$i =~ s/%([a-fA-F0-9][a-fA-F0-9])/pack("C", hex($1))/eg;
+    						$i =~ s/<!--(.|\n)*-->//g;
+    						$ArrayQuery{$v}=$i;
+    					}
+    		  }
+    	  if ($ArrayQuery{amf}) {
+    				$user_agent=$ArrayQuery{amf};
+    	  }
+
+    }    
 
 	if ($user_agent =~ m/Blackberry/i) {	 
 		$user_agent=substr($user_agent,index($user_agent,'BlackBerry'));
@@ -561,10 +599,9 @@ sub handler {
     $id=$CommonLib->readCookie($cookie);
     if ($id eq ""){
                   if ($user_agent) {
-					my $pair;
 					my $lcuser_agent=lc($user_agent);
 	  			    if ($mobile==0) {
-						foreach $pair (%MobileArray) {
+						foreach my $pair (%MobileArray) {
 							if ($user_agent =~ m/$pair/i) {
 								$mobile=1;
 							}
